@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2013 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,6 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.logging.Log;
@@ -67,6 +66,10 @@ import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.responseRenderers.FileResponseRenderer;
 import com.openexchange.exception.OXException;
+import com.openexchange.file.storage.FileStorageFileAccess;
+import com.openexchange.file.storage.composition.IDBasedFileAccess;
+import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
+import com.openexchange.file.storage.infostore.FileMetadata;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.infostore.InfostoreExceptionCodes;
@@ -81,9 +84,6 @@ import com.openexchange.publish.PublicationErrorMessage;
 import com.openexchange.publish.tools.PublicationSession;
 import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSessionAdapter;
-import com.openexchange.user.UserService;
-import com.openexchange.userconf.UserPermissionService;
-
 
 /**
  * {@link InfostoreFileServlet}
@@ -98,7 +98,6 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
     private static final String CONTEXTID = "contextId";
     private static final String SITE = "site";
     private static final String INFOSTORE_ID = "infoId";
-    private static final String INFOSTORE_VERSION = "infoVersion";
 
     private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(InfostoreFileServlet.class));
 
@@ -109,32 +108,20 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
         infostorePublisher = service;
     }
 
-    private static volatile InfostoreFacade infostore;
+    private static volatile IDBasedFileAccessFactory fileFactory;
 
-    public static void setInfostore(final InfostoreFacade service) {
-        infostore = service;
-    }
-
-    private static volatile UserService users;
-
-    public static void setUsers(final UserService service) {
-        users = service;
-    }
-
-    private static volatile UserPermissionService userPermissions;
-
-    public static void setUserPermissions(final UserPermissionService service) {
-        userPermissions = service;
+    public static void setFileFactory(final IDBasedFileAccessFactory service) {
+        fileFactory = service;
     }
 
     private static volatile FileResponseRenderer fileResponseRenderer;
 
     public static void setFileResponseRenderer(final FileResponseRenderer renderer) {
-    	fileResponseRenderer = renderer;
+        fileResponseRenderer = renderer;
     }
 
     @Override
-    protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+    protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws IOException {
         final Map<String, String> args = getPublicationArguments(req);
         boolean startedWriting = false;
         try {
@@ -158,12 +145,9 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
 
             final int infoId = Integer.parseInt(args.get(INFOSTORE_ID));
 
-            final User user = getUser(publication);
-            final UserPermissionBits userPerms = getUserPermissionBits(publication);
+            final DocumentMetadata metadata = loadMetadata(publication, infoId);
 
-            final DocumentMetadata metadata = loadMetadata(publication, infoId, user, userPerms);
-
-            final InputStream fileData = loadFile(publication, infoId, user, userPerms);
+            final InputStream fileData = loadFile(publication, infoId);
 
             startedWriting = true;
             writeFile(new PublicationSession(publication), metadata, fileData, req, resp);
@@ -178,18 +162,11 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
 
     }
 
-    private User getUser(final Publication publication) throws OXException {
-        return users.getUser(publication.getUserId(), publication.getContext());
-    }
-
-    private UserPermissionBits getUserPermissionBits(final Publication publication) throws OXException {
-        return userPermissions.getUserPermissionBits(publication.getUserId(), publication.getContext());
-    }
-
-
-    private DocumentMetadata loadMetadata(final Publication publication, final int infoId, final User user, final UserPermissionBits userPermissions) throws OXException {
+    protected DocumentMetadata loadMetadata(final Publication publication, final int infoId) throws OXException {
         try {
-            return infostore.getDocumentMetadata(infoId, InfostoreFacade.CURRENT_VERSION, publication.getContext(), user, userPermissions);
+            Session session = new PublicationSession(publication);
+            IDBasedFileAccess fileAccess = fileFactory.createAccess(session);
+            return FileMetadata.getMetadata(fileAccess.getFileMetadata(String.valueOf(infoId), FileStorageFileAccess.CURRENT_VERSION));
         } catch (final OXException e) {
             if (InfostoreExceptionCodes.NOT_EXIST.equals(e)) {
                 throw PublicationErrorMessage.NotExist.create(e, new Object[0]);
@@ -199,19 +176,15 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
     }
 
     private void writeFile(final Session session, final DocumentMetadata metadata, final InputStream fileData, final HttpServletRequest req, final HttpServletResponse resp) throws IOException, OXException {
-    	final AJAXRequestData request = AJAXRequestDataTools.getInstance().parseRequest(req, false, false, ServerSessionAdapter.valueOf(session), "/publications/infostore", resp);
-    	final AJAXRequestResult result = new AJAXRequestResult(new FileHolder(fileData, metadata.getFileSize(), metadata.getFileMIMEType(), metadata.getFileName()), "file");
+        final AJAXRequestData request = AJAXRequestDataTools.getInstance().parseRequest(req, false, false, ServerSessionAdapter.valueOf(session), "/publications/infostore", resp);
+        final AJAXRequestResult result = new AJAXRequestResult(new FileHolder(fileData, metadata.getFileSize(), metadata.getFileMIMEType(), metadata.getFileName()), "file");
 
-    	fileResponseRenderer.write(request, result, req, resp);
+        fileResponseRenderer.write(request, result, req, resp);
     }
 
-    private static final boolean isIE(final HttpServletRequest req) {
-        final String userAgent = req.getHeader("User-Agent");
-        return null != userAgent && userAgent.contains("MSIE");
-    }
-
-    private InputStream loadFile(final Publication publication, final int infoId, final User user, final UserPermissionBits userPermissions) throws OXException {
-        return infostore.getDocument(infoId, InfostoreFacade.CURRENT_VERSION, publication.getContext(), user, userPermissions);
+    private InputStream loadFile(final Publication publication, final int infoId) throws OXException {
+        final IDBasedFileAccess fileAccess = fileFactory.createAccess(new PublicationSession(publication));
+        return fileAccess.getDocument(String.valueOf(infoId), FileStorageFileAccess.CURRENT_VERSION);
     }
 
     private Map<String, String> getPublicationArguments(final HttpServletRequest req) throws UnsupportedEncodingException {
@@ -226,7 +199,7 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
         }
 
         final String site = Strings.join(decode(normalized.subList(1, normalized.size()-2), req), "/");
-        final Map<String, String> args = new HashMap<String, String>();
+        final Map<String, String> args = new HashMap<String, String>(6);
         args.put(CONTEXTID, normalized.get(0));
         args.put(SITE, site);
         args.put(SECRET, req.getParameter(SECRET));
